summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorxCrystal <rgr.crystal@gmail.com>2018-03-05 20:16:05 +0100
committerxCrystal <rgr.crystal@gmail.com>2018-03-05 20:16:05 +0100
commit525242f4987903746596e828fff657aaed10105b (patch)
tree65c5ca5feff407d51d38aa44a5dae6501d881e11 /src
parent242b529459eb4b8bc26f298568fbf0a82e2112d3 (diff)
TX_SYMBOL constants and clean up text
Diffstat (limited to 'src')
-rw-r--r--src/constants/text_constants.asm43
-rw-r--r--src/engine/bank6.asm12
-rw-r--r--src/engine/home.asm16
-rw-r--r--src/text/text1.asm26
-rw-r--r--src/text/text10.asm30
-rw-r--r--src/text/text11.asm18
-rw-r--r--src/text/text12.asm10
-rw-r--r--src/text/text2.asm4
-rw-r--r--src/text/text3.asm38
-rw-r--r--src/text/text4.asm4
-rw-r--r--src/text/text5.asm26
-rw-r--r--src/text/text6.asm24
-rw-r--r--src/text/text7.asm24
-rw-r--r--src/text/text8.asm2
-rw-r--r--src/text/text9.asm28
15 files changed, 162 insertions, 143 deletions
diff --git a/src/engine/bank6.asm b/src/engine/bank6.asm
index 82e9cdd..1a85a24 100644
--- a/src/engine/bank6.asm
+++ b/src/engine/bank6.asm
@@ -56,16 +56,16 @@ _CopyCardNameAndLevel: ; 18000 (6:4000)
ld a, [wLoadedCard1Level]
or a
jr z, .done
- ld a, TX_LARGE
+ ld a, TX_SYMBOL
ld [hli], a
- ld [hl], $11 ; Lv
+ ld [hl], LOW("<Lv>")
inc hl
ld a, [wLoadedCard1Level]
cp 10
jr c, .one_digit
- ld [hl], TX_LARGE
+ ld [hl], TX_SYMBOL
inc hl
- ld b, $20 - 1
+ ld b, LOW("<0>") - 1
.first_digit_loop
inc b
sub 10
@@ -74,9 +74,9 @@ _CopyCardNameAndLevel: ; 18000 (6:4000)
ld [hl], b ; first digit
inc hl
.one_digit
- ld [hl], TX_LARGE
+ ld [hl], TX_SYMBOL
inc hl
- add $20
+ add LOW("<0>")
ld [hl], a ; last (or only) digit
inc hl
.done
diff --git a/src/text/text1.asm b/src/text/text1.asm
index e207c2e..b39e449 100644
--- a/src/text/text1.asm
+++ b/src/text/text1.asm
@@ -304,27 +304,27 @@ Text0046: ; 3681b (d:681b)
done
Text0047: ; 36848 (d:6848)
- db TX_GRASS
+ db "<GRASS>"
done
Text0048: ; 3684b (d:684b)
- db TX_FIRE
+ db "<FIRE>"
done
Text0049: ; 3684e (d:684e)
- db TX_WATER
+ db "<WATER>"
done
Text004a: ; 36851 (d:6851)
- db TX_LIGHTNING
+ db "<LIGHTNING>"
done
Text004b: ; 36854 (d:6854)
- db TX_FIGHTING
+ db "<FIGHTING>"
done
Text004c: ; 36857 (d:6857)
- db TX_PSYCHIC
+ db "<PSYCHIC>"
done
Text004d: ; 3685a (d:685a)
@@ -724,19 +724,19 @@ Text009d: ; 371f7 (d:71f7)
done
Text009e: ; 3720c (d:720c)
- text TX_GRASS, " Pokémon"
+ text "<GRASS> Pokémon"
line ""
- text TX_FIRE, " Pokémon"
+ text "<FIRE> Pokémon"
line ""
- text TX_WATER, " Pokémon"
+ text "<WATER> Pokémon"
line ""
- text TX_LIGHTNING, " Pokémon"
+ text "<LIGHTNING> Pokémon"
line ""
- text TX_FIGHTING, " Pokémon"
+ text "<FIGHTING> Pokémon"
line ""
- text TX_PSYCHIC, " Pokémon"
+ text "<PSYCHIC> Pokémon"
line ""
- text TX_COLORLESS, " Pokémon"
+ text "<COLORLESS> Pokémon"
line "Trainer Card"
line "Energy Card"
done
diff --git a/src/text/text10.asm b/src/text/text10.asm
index e21b74c..013e5da 100644
--- a/src/text/text10.asm
+++ b/src/text/text10.asm
@@ -777,7 +777,7 @@ EmberName: ; 59e0e (16:5e0e)
done
EmberDescription: ; 59e15 (16:5e15)
- text "Discard 1 ", TX_FIRE, " Energy card attached to"
+ text "Discard 1 <FIRE> Energy card attached to"
line "Charmander in order to use this"
line "attack."
done
@@ -802,7 +802,7 @@ FlamethrowerName: ; 59ee6 (16:5ee6)
done
CharmeleonsFlamethrowerDescription: ; 59ef4 (16:5ef4)
- text "Discard 1 ", TX_FIRE, " Energy card attached to"
+ text "Discard 1 <FIRE> Energy card attached to"
line "Charmeleon in order to use this"
line "attack."
done
@@ -829,7 +829,7 @@ EnergyBurnDescription: ; 59fb8 (16:5fb8)
text "As often as you like during your"
line "turn (before your attack), you may"
line "turn all Energy attached to"
- line "Charizard into ", TX_FIRE, " Energy for the"
+ line "Charizard into <FIRE> Energy for the"
line "rest of the turn. This power can't"
line "be used if Charizard is Asleep,"
line "Confused, or Paralyzed."
@@ -884,7 +884,7 @@ FireBlastName: ; 5a231 (16:6231)
done
FireBlastDescription: ; 5a23d (16:623d)
- text "Discard 1 ", TX_FIRE, " Energy card attached"
+ text "Discard 1 <FIRE> Energy card attached"
line "to Ninetales in order to use this"
line "attack."
done
@@ -968,7 +968,7 @@ FlamesOfRageName: ; 5a5d8 (16:65d8)
done
FlamesOfRageDescription: ; 5a5e8 (16:65e8)
- text "Discard 2 ", TX_FIRE, " Energy cards attached"
+ text "Discard 2 <FIRE> Energy cards attached"
line "to Arcanine in order to use this"
line "attack. This attack does 40 damage"
line "plus 10 more damage for each damage"
@@ -986,7 +986,7 @@ Arcanine1Description: ; 5a694 (16:6694)
done
ArcaninesFlamethrowerDescription: ; 5a6ed (16:66ed)
- text "Discard 1 ", TX_FIRE, " Energy card attached to"
+ text "Discard 1 <FIRE> Energy card attached to"
line "Arcanine in order to use this"
line "attack."
done
@@ -1068,7 +1068,7 @@ FirePunchName: ; 5a9b3 (16:69b3)
done
FirePunchDescription: ; 5a9bf (16:69bf)
- text "Discard 1 ", TX_FIRE, " Energy card attached to"
+ text "Discard 1 <FIRE> Energy card attached to"
line "Magmar in order to use this attack."
done
@@ -1128,7 +1128,7 @@ Flareon1Description: ; 5abe1 (16:6be1)
done
FlareonsFlamethrowerDescription: ; 5ac46 (16:6c46)
- text "Discard 1 ", TX_FIRE, " Energy card attached to"
+ text "Discard 1 <FIRE> Energy card attached to"
line "Flareon in order to use this attack."
done
@@ -1147,7 +1147,7 @@ WildfireName: ; 5acf6 (16:6cf6)
done
WildfireDescription: ; 5ad00 (16:6d00)
- text "You may discard any number of ", TX_FIRE, ""
+ text "You may discard any number of <FIRE>"
line "Energy cards attached to Moltres"
line "when you use this attack. If you do,"
line "discard that many cards from the top"
@@ -1172,7 +1172,7 @@ FiregiverDescription: ; 5ae1e (16:6e1e)
text "When you put Moltres into play"
line "during your turn (not during"
line "set-up), put from 1 to 4 (chosen at"
- line "random) ", TX_FIRE, " Energy cards from your"
+ line "random) <FIRE> Energy cards from your"
line "deck into your hand. Shuffle your"
line "deck afterward."
done
@@ -1244,8 +1244,8 @@ RainDanceName: ; 5b159 (16:7159)
RainDanceDescription: ; 5b165 (16:7165)
text "As often as you like during your"
line "turn (before your attack), you may"
- line "attach 1 ", TX_WATER, " Energy card to 1 of"
- line "your ", TX_WATER, " Pokémon. (This doesn't use"
+ line "attach 1 <WATER> Energy card to 1 of"
+ line "your <WATER> Pokémon. (This doesn't use"
line "up your 1 Energy card attachment"
line "for the turn.)"
done
@@ -1262,7 +1262,7 @@ HydroPumpName: ; 5b267 (16:7267)
HydroPumpDescription: ; 5b273 (16:7273)
text "Does 40 damage plus 10 more damage"
- line "for each ", TX_WATER, " Energy attached to"
+ line "for each <WATER> Energy attached to"
line "Blastoise but not used to pay for"
line "this attack's Energy cost. You can't"
line "add more than 20 damage in this way."
@@ -1335,7 +1335,7 @@ WaterGunName: ; 5b53c (16:753c)
PoliwagsWaterGunDescription: ; 5b547 (16:7547)
text "Does 10 damage plus 10 more damage"
- line "for each ", TX_WATER, " Energy attached to"
+ line "for each <WATER> Energy attached to"
line "Poliwag but not used to pay for"
line "this attack's Energy cost. You can't"
line "add more than 20 damage in this way."
@@ -1382,7 +1382,7 @@ PoliwrathName: ; 5b74f (16:774f)
PoliwrathsWaterGunDescription: ; 5b75a (16:775a)
text "Does 30 damage plus 10 more damage"
- line "for each ", TX_WATER, " Energy attached to"
+ line "for each <WATER> Energy attached to"
line "Poliwrath but not used to pay for"
line "this attack's Energy cost. You"
line "can't add more than 20 damage in"
diff --git a/src/text/text11.asm b/src/text/text11.asm
index 9dd0a02..673150d 100644
--- a/src/text/text11.asm
+++ b/src/text/text11.asm
@@ -10,7 +10,7 @@ SeadraName: ; 5c05d (17:405d)
SeadrasWaterGunDescription: ; 5c065 (17:4065)
text "Does 20 damage plus 10 more damage"
- line "for each ", TX_WATER, " Energy attached to"
+ line "for each <WATER> Energy attached to"
line "Seadra but not used to pay for this"
line "attack's Energy cost. You can't add"
line "more than 20 damage in this way."
@@ -44,7 +44,7 @@ GoldeenKind: ; 5c202 (17:4202)
GoldeenDescription: ; 5c20c (17:420c)
text "Its tail fin billows like an elegant"
line "ballroom dress, giving it the"
- line "nickname \"Water Queen.\""
+ line "nickname ”Water Queen.”"
done
SeakingName: ; 5c268 (17:4268)
@@ -88,7 +88,7 @@ RecoverName: ; 5c352 (17:4352)
done
StarmiesRecoverDescription: ; 5c35b (17:435b)
- text "Discard 1 ", TX_WATER, " Energy card attached to"
+ text "Discard 1 <WATER> Energy card attached to"
line "Starmie in order to use this attack."
line "Remove all damage counters from"
line "Starmie."
@@ -159,7 +159,7 @@ LaprasName: ; 5c58f (17:458f)
LaprasWaterGunDescription: ; 5c597 (17:4597)
text "Does 10 damage plus 10 more damage"
- line "for each ", TX_WATER, " Energy attached to"
+ line "for each <WATER> Energy attached to"
line "Lapras but not used to pay for this"
line "attack's Energy cost. You can't add"
line "more than 20 damage in this way."
@@ -201,7 +201,7 @@ Vaporeon1Description: ; 5c717 (17:4717)
VaporeonsWaterGunDescription: ; 5c77b (17:477b)
text "Does 30 damage plus 10 more damage"
- line "for each ", TX_WATER, " Energy attached to"
+ line "for each <WATER> Energy attached to"
line "Vaporeon but not used to pay for"
line "this attack's Energy cost. You can't"
line "add more than 20 damage in this way."
@@ -234,7 +234,7 @@ ClairvoyanceDescription: ; 5c8b5 (17:48b5)
OmanytesWaterGunDescription: ; 5c932 (17:4932)
text "Does 10 damage plus 10 more damage"
- line "for each ", TX_WATER, " Energy attached to"
+ line "for each <WATER> Energy attached to"
line "Omanyte but not used to pay for this"
line "attack's Energy cost. You can't add"
line "more than 20 damage in this way."
@@ -256,7 +256,7 @@ OmastarName: ; 5ca3e (17:4a3e)
OmastarsWaterGunDescription: ; 5ca47 (17:4a47)
text "Does 20 damage plus 10 more damage"
- line "for each ", TX_WATER, " Energy attached to"
+ line "for each <WATER> Energy attached to"
line "Omastar but not used to pay for this"
line "attack's Energy cost. You can't add"
line "more than 20 damage in this way."
@@ -1145,7 +1145,7 @@ CallforFriendName: ; 5f33e (17:733e)
done
CallforFriendDescription: ; 5f34f (17:734f)
- text "Search your deck for a ", TX_FIGHTING, " Basic"
+ text "Search your deck for a <FIGHTING> Basic"
line "Pokémon card and put it onto your"
line "Bench. Shuffle your deck afterward."
line "(You can't use this attack if your"
@@ -1405,7 +1405,7 @@ KadabraName: ; 5fed3 (17:7ed3)
done
KadabrasRecoverDescription: ; 5fedc (17:7edc)
- text "Discard 1 ", TX_PSYCHIC, " Energy card attached to"
+ text "Discard 1 <PSYCHIC> Energy card attached to"
line "Kadabra in order to use this attack."
line "Remove all damage counters from"
line "Kadabra."
diff --git a/src/text/text12.asm b/src/text/text12.asm
index ed86081..80b3530 100644
--- a/src/text/text12.asm
+++ b/src/text/text12.asm
@@ -51,7 +51,7 @@ ScavengeName: ; 602b5 (18:42b5)
done
ScavengeDescription: ; 602bf (18:42bf)
- text "Discard 1 ", TX_PSYCHIC, " Energy card attached"
+ text "Discard 1 <PSYCHIC> Energy card attached"
line "to Slowpoke in order to use this"
line "attack. Put a Trainer card from your"
line "discard pile into your hand."
@@ -103,7 +103,7 @@ DestinyBondName: ; 6050e (18:450e)
done
DestinyBondDescription: ; 6051c (18:451c)
- text "Discard 1 ", TX_PSYCHIC, " Energy card attached to"
+ text "Discard 1 <PSYCHIC> Energy card attached to"
line "Gastly in order to use this attack."
line "If a Pokémon Knocks Out Gastly"
line "during your opponent's next turn,"
@@ -334,7 +334,7 @@ PsychicDescription: ; 60ee9 (18:4ee9)
done
BarrierDescription: ; 60f45 (18:4f45)
- text "Discard 1 ", TX_PSYCHIC, " Energy card attached to"
+ text "Discard 1 <PSYCHIC> Energy card attached to"
line "Mewtwo in order to use this attack."
line "During your opponent's next turn,"
line "prevent all effects of attacks,"
@@ -889,7 +889,7 @@ RetreatAidName: ; 62796 (18:6796)
RetreatAidDescription: ; 627a3 (18:67a3)
text "As long as Dodrio is Benched, pay"
- line TX_COLORLESS, " less to retreat your Active"
+ line "<COLORLESS> less to retreat your Active"
line "Pokémon."
done
@@ -1250,7 +1250,7 @@ ImakuniDescription: ; 635cb (18:75cb)
line "Basic Pokémon, but you can't."
line "A mysterious creature not listed in"
line "the Pok`dex. He asks kids around the"
- line "world,\"Who is cuter-Pikachu or me?\""
+ line "world,”Who is cuter-Pikachu or me?”"
done
PokemonTraderName: ; 6369f (18:769f)
diff --git a/src/text/text2.asm b/src/text/text2.asm
index 511880d..d02bdbd 100644
--- a/src/text/text2.asm
+++ b/src/text/text2.asm
@@ -1101,7 +1101,7 @@ Text01c4: ; 3ab08 (e:6b08)
line "Energy to use Waterfall."
line "You need to attach a Psychic Energy"
line "card to Seaking."
- line TX_COLORLESS, " means any Energy card."
+ line "<COLORLESS> means any Energy card."
line "Now you can use Waterfall."
line "Keep the Water Energy card for"
line "other Pokémon."
@@ -1553,7 +1553,7 @@ Text0221: ; 3b8f2 (e:78f2)
line $03,$39,$70,$03,$3a,$70,$03,$3b,$70,$03,$3c,$70,$03,$3d,$70,$03,$3e,$70,$03,$3f,$70,$03,$40,$70,$03,$41,""
line $03,$42,$70,$03,$43,$70,$03,$44,$70,$03,$45,$70,$03,$46,$70,$03,$47,$70,$03,$48,$70,$03,$49,$70,$6e,""
line $6f,$70,$03,$5d,$70,$6a,$70,$6b,$70,$77,$70,$60,$70,$61,$70,$62,$70,$63,""
- line $64,$70,$65,$70,$66,$70,$67,$70,$68,$70,$69,$70,$05,$13,$70, TX_LVL, $70,$70,""
+ line $64,$70,$65,$70,$66,$70,$67,$70,$68,$70,$69,$70,$05,$13,$70,$05,$11,$70,$70,""
line $70,$70,$70,$70,$70,$70,$70,$70,$70,$70,$70,$70,$70,$70,$70,$70,$70
done
diff --git a/src/text/text3.asm b/src/text/text3.asm
index d23c296..3231b66 100644
--- a/src/text/text3.asm
+++ b/src/text/text3.asm
@@ -808,10 +808,10 @@ Text0315: ; 3dcb2 (f:5cb2)
line "your Pokémon, making them able"
line "to Attack."
line "There are 7 types of Energy Cards"
- line "[", TX_GRASS, " Grass] [", TX_FIRE, " Fire]"
- line "[", TX_WATER, " Water] [", TX_LIGHTNING, " Lightning]"
- line "[", TX_PSYCHIC, " Psychic] [", TX_FIGHTING, " Fighting]"
- line "and [", TX_COLORLESS, " Double Colorless]"
+ line "[<GRASS> Grass] [<FIRE> Fire]"
+ line "[<WATER> Water] [<LIGHTNING> Lightning]"
+ line "[<PSYCHIC> Psychic] [<FIGHTING> Fighting]"
+ line "and [<COLORLESS> Double Colorless]"
line "You may only play 1 Energy Card"
line "from your Hand per turn."
done
@@ -1347,12 +1347,12 @@ Text0379: ; 3efc3 (f:6fc3)
line "and Pokémon card collecting!"
line "One day,"
line TX_RAM1, " heard a rumor:"
- line " \"The Legendary Pokémon Cards..."
+ line " ”The Legendary Pokémon Cards..."
line " the extremely rare and powerful "
line " cards held by Pokémon Trading "
line " Card Game's greatest players... "
line " The Grand Masters are searching"
- line " for one to inherit the legend!\""
+ line " for one to inherit the legend!”"
line "Dreaming of inheriting the"
line "Legendary Pokémon Cards,"
line TX_RAM1, " visits the Pokémon"
@@ -1846,51 +1846,51 @@ Text03e7: ; 3f823 (f:7823)
done
Text03e8: ; 3f82a (f:782a)
- text TX_LVL, "60 MEWTWO "
+ text "<Lv>60 MEWTWO "
done
Text03e9: ; 3f838 (f:7838)
- text TX_LVL, "8 MEW "
+ text "<Lv>8 MEW "
done
Text03ea: ; 3f842 (f:7842)
- text TX_LVL, "34 ARCANINE"
+ text "<Lv>34 ARCANINE"
done
Text03eb: ; 3f851 (f:7851)
- text TX_LVL, "16 PIKACHU"
+ text "<Lv>16 PIKACHU"
done
Text03ec: ; 3f85f (f:785f)
- text TX_LVL, "13 SURFING PIKACHU"
+ text "<Lv>13 SURFING PIKACHU"
done
Text03ed: ; 3f875 (f:7875)
- text TX_LVL, "20 ELECTABUZZ"
+ text "<Lv>20 ELECTABUZZ"
done
Text03ee: ; 3f886 (f:7886)
- text TX_LVL, "9 SLOWPOKE"
+ text "<Lv>9 SLOWPOKE"
done
Text03ef: ; 3f894 (f:7894)
- text TX_LVL, "12 JIGGLYPUFF"
+ text "<Lv>12 JIGGLYPUFF"
done
Text03f0: ; 3f8a5 (f:78a5)
- text TX_LVL, "68 ZAPDOS"
+ text "<Lv>68 ZAPDOS"
done
Text03f1: ; 3f8b2 (f:78b2)
- text TX_LVL, "37 MOLTRES"
+ text "<Lv>37 MOLTRES"
done
Text03f2: ; 3f8c0 (f:78c0)
- text TX_LVL, "37 ARTICUNO"
+ text "<Lv>37 ARTICUNO"
done
Text03f3: ; 3f8cf (f:78cf)
- text TX_LVL, "41 DRAGONITE"
+ text "<Lv>41 DRAGONITE"
done
Text03f4: ; 3f8df (f:78df)
@@ -1898,7 +1898,7 @@ Text03f4: ; 3f8df (f:78df)
done
Text03f5: ; 3f8f7 (f:78f7)
- text TX_LVL, "12 FLYING PIKACHU"
+ text "<Lv>12 FLYING PIKACHU"
done
Text03f6: ; 3f90c (f:790c)
diff --git a/src/text/text4.asm b/src/text/text4.asm
index d8f4929..dd9f326 100644
--- a/src/text/text4.asm
+++ b/src/text/text4.asm
@@ -320,7 +320,7 @@ Text0419: ; 41965 (10:5965)
done
Text041a: ; 4199b (10:599b)
- text "\"Pokémon Trading Cards 101\""
+ text "”Pokémon Trading Cards 101”"
done
Text041b: ; 419b8 (10:59b8)
@@ -786,7 +786,7 @@ Text0463: ; 430ab (10:70ab)
line "me so many cards,"
line "please accept this card as a gift"
line "from me to you."
- line "It's a ", TX_LVL, "16 Pikachu."
+ line "It's a <Lv>16 Pikachu."
line "Please take good care of it!"
done
diff --git a/src/text/text5.asm b/src/text/text5.asm
index 9316b29..706ab09 100644
--- a/src/text/text5.asm
+++ b/src/text/text5.asm
@@ -692,7 +692,7 @@ Text04f4: ; 46aae (11:6aae)
line "for Game Boy includes many "
line "original cards, like the "
line ""
- text TX_LVL, "14 Meowth with the Cat Punch "
+ text "<Lv>14 Meowth with the Cat Punch "
line "attack. There are many new cards,"
line "so go search them out!"
done
@@ -720,7 +720,7 @@ Text04f8: ; 46c3f (11:6c3f)
line "Pokémon and have no weaknesses."
line "They can attack with any type"
line "of Energy card - they are truly"
- line "worthy of the name \"dragon!\""
+ line "worthy of the name ”dragon!”"
done
Text04f9: ; 46cf5 (11:6cf5)
@@ -743,7 +743,7 @@ Text04fb: ; 46dcb (11:6dcb)
Text04fc: ; 46dec (11:6dec)
text "The first of the Legendary Pokémon"
- line "Cards is ", TX_LVL, "37 Moltres. With"
+ line "Cards is <Lv>37 Moltres. With"
line "Firegiver, you can place Fire"
line "Energy cards in your hand! Also,"
line "Dive Bomb is a powerful attack!"
@@ -757,7 +757,7 @@ Text04fd: ; 46ec2 (11:6ec2)
Text04fe: ; 46ee3 (11:6ee3)
text "The second Legendary Pokémon Card"
- line "is ", TX_LVL, "68 Zapdos. With Peal of"
+ line "is <Lv>68 Zapdos. With Peal of"
line "Thunder, just putting this card on"
line "the bench causes damage!"
line "Also, Big Thunder is a powerful"
@@ -771,7 +771,7 @@ Text04ff: ; 46fb8 (11:6fb8)
Text0500: ; 46fd9 (11:6fd9)
text "The third Legendary Pokémon Card"
- line "is ", TX_LVL, "37 Articuno. Its Quickfreeze"
+ line "is <Lv>37 Articuno. Its Quickfreeze"
line "will paralyze opponents' Pokémon"
line "when the card is put in play!"
line "Also, Ice Breath is a powerful"
@@ -785,7 +785,7 @@ Text0501: ; 470b3 (11:70b3)
Text0502: ; 470d4 (11:70d4)
text "The fourth Legendary Pokémon Card"
- line "is ", TX_LVL, "41 Dragonite. Its Healing"
+ line "is <Lv>41 Dragonite. Its Healing"
line "Wind will heal damage done to "
line "Pokémon when this card is played!"
line "Also, Slam is a powerful attack!"
@@ -823,14 +823,14 @@ Text0507: ; 47334 (11:7334)
done
Text0508: ; 47346 (11:7346)
- text "\"Those in search of the Legendary"
+ text "”Those in search of the Legendary"
line " Pokémon Cards..."
line " Defeat the Masters of the 8 Clubs"
line " and attain the 8 Medals."
line " Once attained, defeat the Grand"
line " Master here at Pokémon Dome..."
line " Then you shall inherit"
- line " the Legendary Pokémon Cards.\""
+ line " the Legendary Pokémon Cards.”"
done
Text0509: ; 47430 (11:7430)
@@ -927,7 +927,7 @@ Text0516: ; 479a4 (11:79a4)
text "I'm the one who's going to"
line "defeat 3 opponents! The prize, "
line ""
- text TX_LVL, "60 Mewtwo, belongs to me!"
+ text "<Lv>60 Mewtwo, belongs to me!"
line "You just sit tight and watch me win!"
line "See Ya! Ha ha ha ha ha ha!"
done
@@ -954,7 +954,7 @@ Text0519: ; 47b25 (11:7b25)
Text051a: ; 47b47 (11:7b47)
text "The Challenge Cup is over! I"
line "defeated 3 opponents and won"
- line "the prize - ", TX_LVL, "60 Mewtwo!"
+ line "the prize - <Lv>60 Mewtwo!"
line "See ya! Ha ha ha ha ha ha!"
done
@@ -966,7 +966,7 @@ Text051b: ; 47bb6 (11:7bb6)
Text051c: ; 47bd7 (11:7bd7)
text "The Challenge Cup is over! I"
line "defeated 3 opponents and won"
- line "the prize - ", TX_LVL, "60 Mewtwo!"
+ line "the prize - <Lv>60 Mewtwo!"
line "I guess you could try entering"
line "the next Challenge Cup, but "
line "you won't have a chance since "
@@ -983,7 +983,7 @@ Text051e: ; 47cd1 (11:7cd1)
text "No matter who enters the Challenge"
line "Cup, I'll be the winner! "
line ""
- text TX_LVL, "8 Mew, this Cup's prize, will "
+ text "<Lv>8 Mew, this Cup's prize, will "
line "belong to me! Why don't you just"
line "give up and go home!"
line "See ya! Ha ha ha ha ha ha!"
@@ -1012,7 +1012,7 @@ Text0522: ; 47e73 (11:7e73)
line "over! What? Who won?"
line "Who do you expect!?! Me, of "
line "course! The prize belongs to"
- line "me! ", TX_LVL, "8 Mew! See ya!"
+ line "me! <Lv>8 Mew! See ya!"
line "Ha ha ha ha ha ha!"
done
diff --git a/src/text/text6.asm b/src/text/text6.asm
index f45212f..a99de27 100644
--- a/src/text/text6.asm
+++ b/src/text/text6.asm
@@ -1,7 +1,7 @@
Text0524: ; 48000 (12:4000)
text "The Challenge Cup is over already! "
line "Too bad you couldn't enter!"
- line "The prize belongs to me! ", TX_LVL, "8 Mew!"
+ line "The prize belongs to me! <Lv>8 Mew!"
line "You really should enter the next"
line "Challenge Cup! But then again, "
line "why bother, since I'll also win "
@@ -55,14 +55,14 @@ Text052b: ; 48376 (12:4376)
text "The first Challenge Cup is"
line "now underway!"
line "Defeat 3 opponents to win the"
- line "wonderful prize of ", TX_LVL, "60 Mewtwo!"
+ line "wonderful prize of <Lv>60 Mewtwo!"
done
Text052c: ; 483de (12:43de)
text "The second Challenge Cup is"
line "now under way!"
line "Defeat 3 opponents to win the"
- line "wonderful prize of ", TX_LVL, "8 Mew!"
+ line "wonderful prize of <Lv>8 Mew!"
done
Text052d: ; 48444 (12:4444)
@@ -150,7 +150,7 @@ Text053b: ; 487c0 (12:47c0)
text "Ha ha ha! How about that!?!"
line "I win!!"
line "2 more opponents to go and"
- line "the ", TX_LVL, "8 Mew belongs to me!"
+ line "the <Lv>8 Mew belongs to me!"
done
Text053c: ; 4881b (12:481b)
@@ -193,14 +193,14 @@ Text0542: ; 4893d (12:493d)
text "Hey, ", TX_RAM1, "!"
line "I'm not gonna lose to you!"
line ""
- text TX_LVL, "60 Mewtwo belongs to me!!!"
+ text "<Lv>60 Mewtwo belongs to me!!!"
done
Text0543: ; 4897f (12:497f)
text TX_RAM1, "!"
line "I'm going to defeat you!"
line ""
- text TX_LVL, "8 Mew belongs to me!!!"
+ text "<Lv>8 Mew belongs to me!!!"
done
Text0544: ; 489b6 (12:49b6)
@@ -878,7 +878,7 @@ Text05b8: ; 4a898 (12:6898)
Text05b9: ; 4a8d2 (12:68d2)
text "The Legendary Pokémon Cards"
line "speak to you..."
- line " \"You who have inherited us..."
+ line " ”You who have inherited us..."
line " Great Card Master! "
line " Our Master must not forget:"
line " Inheriting us does not make you"
@@ -891,7 +891,7 @@ Text05b9: ; 4a8d2 (12:68d2)
line " of all, the ability to love the"
line " Pokémon Trading Card Game"
line " no matter what - win or lose!"
- line " A new journey has just begun...\""
+ line " A new journey has just begun...”"
done
Text05ba: ; 4aaad (12:6aad)
@@ -907,7 +907,7 @@ Text05bb: ; 4aaed (12:6aed)
Text05bc: ; 4ab23 (12:6b23)
text "The Legendary Pokémon Cards"
line "speak to you..."
- line " \"You who have inherited us..."
+ line " ”You who have inherited us..."
line " Great Card Master!"
line " There are no cards left for us"
line " to give you, but do not forget:"
@@ -921,7 +921,7 @@ Text05bc: ; 4ab23 (12:6b23)
line " all, the ability to love the"
line " Pokémon Trading Card Game no"
line " matter what - win or lose!"
- line " A new journey has just begun...\""
+ line " A new journey has just begun...”"
done
Text05bd: ; 4ad20 (12:6d20)
@@ -1129,8 +1129,8 @@ Text05d7: ; 4ba32 (12:7a32)
line "by attacking. Pokémon need Energy "
line "cards in order to attack."
line "For example, the energy required "
- line "for Seaking's Waterfall is ", TX_WATER, TX_COLORLESS, "."
- line TX_WATER, TX_COLORLESS, " stands for 1 Water Energy "
+ line "for Seaking's Waterfall is <WATER><COLORLESS>."
+ line "<WATER><COLORLESS> stands for 1 Water Energy "
line "card and another Energy card of "
line "any type. The energy required "
line "differs according to the attack."
diff --git a/src/text/text7.asm b/src/text/text7.asm
index c34d2a8..56dddec 100644
--- a/src/text/text7.asm
+++ b/src/text/text7.asm
@@ -382,25 +382,25 @@ Text060e: ; 4d767 (13:5767)
Text060f: ; 4d7fc (13:57fc)
text "Hey! Kid!"
- line "I've got a ", TX_LVL, "20 Electabuzz,"
+ line "I've got a <Lv>20 Electabuzz,"
line "but what I really want is"
- line "a ", TX_LVL, "35 Electabuzz!"
+ line "a <Lv>35 Electabuzz!"
line "Hey! Kid! Do you have a"
line ""
- text TX_LVL, "35 Electabuzz?"
+ text "<Lv>35 Electabuzz?"
done
Text0610: ; 4d87a (13:587a)
text "Hey! Kid!"
line "We meet again!"
- line "Do you have a ", TX_LVL, "35 Electabuzz?"
+ line "Do you have a <Lv>35 Electabuzz?"
line "Come on! Trade it for my"
line ""
- text TX_LVL, "20 Electabuzz!"
+ text "<Lv>20 Electabuzz!"
done
Text0611: ; 4d8de (13:58de)
- text "Trade your ", TX_LVL, "35 Electabuzz?"
+ text "Trade your <Lv>35 Electabuzz?"
done
Text0612: ; 4d8fb (13:58fb)
@@ -413,14 +413,14 @@ Text0612: ; 4d8fb (13:58fb)
Text0613: ; 4d938 (13:5938)
text "Hey, kid!"
line "It's not cool to lie!"
- line "You don't own a ", TX_LVL, "35 Electabuzz!"
+ line "You don't own a <Lv>35 Electabuzz!"
line "You could get hurt lying to me, kid!"
done
Text0614: ; 4d99f (13:599f)
text "You're gonna trade me your"
line ""
- text TX_LVL, "35 Electabuzz?"
+ text "<Lv>35 Electabuzz?"
line "Way cool!...Hey! Wait, kid!"
line "That card's in your Deck!"
line "It isn't cool to take that card!"
@@ -432,10 +432,10 @@ Text0614: ; 4d99f (13:599f)
Text0615: ; 4da6d (13:5a6d)
text "You're gonna trade me your"
line ""
- text TX_LVL, "35 Electabuzz? Way cool, kid!"
+ text "<Lv>35 Electabuzz? Way cool, kid!"
line "OK, I'll trade you my"
line ""
- text TX_LVL, "20 Electabuzz for it!"
+ text "<Lv>20 Electabuzz for it!"
done
Text0616: ; 4dad9 (13:5ad9)
@@ -445,8 +445,8 @@ Text0616: ; 4dad9 (13:5ad9)
Text0617: ; 4dafe (13:5afe)
text "Whoa! Cool, kid! Thanks for "
- line "that ", TX_LVL, "35 Electabuzz! "
- line "My ", TX_LVL, "20 Electabuzz is a cool card!"
+ line "that <Lv>35 Electabuzz! "
+ line "My <Lv>20 Electabuzz is a cool card!"
line "Charge it up with Electabuzz!"
done
diff --git a/src/text/text8.asm b/src/text/text8.asm
index 5bc2255..176964e 100644
--- a/src/text/text8.asm
+++ b/src/text/text8.asm
@@ -210,7 +210,7 @@ Text06a2: ; 50a9e (14:4a9e)
line "checked the wall!"
line ""
text TX_RAM1, ""
- line "found a ", TX_LVL, "9 Slowpoke!"
+ line "found a <Lv>9 Slowpoke!"
done
Text06a3: ; 50acc (14:4acc)
diff --git a/src/text/text9.asm b/src/text/text9.asm
index 56a7a19..9beb35d 100644
--- a/src/text/text9.asm
+++ b/src/text/text9.asm
@@ -1153,27 +1153,27 @@ Text07f5: ; 5736a (15:736a)
done
Text07f6: ; 5736d (15:736d)
- db $03,$50, TX_FIRE, $03,$51
+ db $03,$50, "<FIRE>", $03,$51
done
Text07f7: ; 57374 (15:7374)
- db $03,$50, TX_LIGHTNING, $03,$51
+ db $03,$50, "<LIGHTNING>", $03,$51
done
Text07f8: ; 5737b (15:737b)
- db $03,$50, TX_WATER, $03,$51
+ db $03,$50, "<WATER>", $03,$51
done
Text07f9: ; 57382 (15:7382)
- db $03,$50, TX_FIGHTING, $03,$51
+ db $03,$50, "<FIGHTING>", $03,$51
done
Text07fa: ; 57389 (15:7389)
- db $03,$50, TX_PSYCHIC, $03,$51
+ db $03,$50, "<PSYCHIC>", $03,$51
done
Text07fb: ; 57390 (15:7390)
- db $03,$50, TX_GRASS, $03,$51
+ db $03,$50, "<GRASS>", $03,$51
done
GrassEnergyName: ; 57397 (15:7397)
@@ -1181,7 +1181,7 @@ GrassEnergyName: ; 57397 (15:7397)
done
GrassEnergyDescription: ; 573a5 (15:73a5)
- text "Provides 1 ", TX_GRASS, " Energy."
+ text "Provides 1 <GRASS> Energy."
done
FireEnergyName: ; 573bc (15:73bc)
@@ -1189,7 +1189,7 @@ FireEnergyName: ; 573bc (15:73bc)
done
FireEnergyDescription: ; 573c9 (15:73c9)
- text "Provides 1 ", TX_FIRE, " Energy."
+ text "Provides 1 <FIRE> Energy."
done
WaterEnergyName: ; 573e0 (15:73e0)
@@ -1197,7 +1197,7 @@ WaterEnergyName: ; 573e0 (15:73e0)
done
WaterEnergyDescription: ; 573ee (15:73ee)
- text "Provides 1 ", TX_WATER, " Energy."
+ text "Provides 1 <WATER> Energy."
done
LightningEnergyName: ; 57405 (15:7405)
@@ -1205,7 +1205,7 @@ LightningEnergyName: ; 57405 (15:7405)
done
LightningEnergyDescription: ; 57417 (15:7417)
- text "Provides 1 ", TX_LIGHTNING, " Energy."
+ text "Provides 1 <LIGHTNING> Energy."
done
FightingEnergyName: ; 5742e (15:742e)
@@ -1213,7 +1213,7 @@ FightingEnergyName: ; 5742e (15:742e)
done
FightingEnergyDescription: ; 5743f (15:743f)
- text "Provides 1 ", TX_FIGHTING, " Energy."
+ text "Provides 1 <FIGHTING> Energy."
done
PsychicEnergyName: ; 57456 (15:7456)
@@ -1221,7 +1221,7 @@ PsychicEnergyName: ; 57456 (15:7456)
done
PsychicEnergyDescription: ; 57466 (15:7466)
- text "Provides 1 ", TX_PSYCHIC, " Energy."
+ text "Provides 1 <PSYCHIC> Energy."
done
DoubleColorlessEnergyName: ; 5747d (15:747d)
@@ -1229,7 +1229,7 @@ DoubleColorlessEnergyName: ; 5747d (15:747d)
done
DoubleColorlessEnergyDescription: ; 57496 (15:7496)
- text "Provides ", TX_COLORLESS, TX_COLORLESS, " Energy. (Doesn't"
+ text "Provides <COLORLESS><COLORLESS> Energy. (Doesn't"
line "count as a basic Energy card.) "
line "Colorless Energy can't be used to"
line "pay colored Energy costs. (Any type"
@@ -1340,7 +1340,7 @@ EnergyTransName: ; 57960 (15:7960)
EnergyTransDescription: ; 5796e (15:796e)
text "As often as you like during your"
line "turn (before your attack), you may"
- line "take 1 ", TX_GRASS, " Energy card attached to 1"
+ line "take 1 <GRASS> Energy card attached to 1"
line "of your Pokémon and attach it to a"
line "different one. This power can't be"
line "used if Venusaur is Asleep,"
diff --git a/src/constants/text_constants.asm b/src/constants/text_constants.asm
index 133f76e..b161a63 100644
--- a/src/constants/text_constants.asm
+++ b/src/constants/text_constants.asm
@@ -1,5 +1,5 @@
TX_END EQU $00
-TX_LARGE EQU $05
+TX_SYMBOL EQU $05
TX_START EQU $06
TX_RAM1 EQU $09
TX_LINE EQU "\n" ; $0a
@@ -13,15 +13,34 @@ done EQUS "db TX_END"
charmap "é", "`"
charmap "♂", "$"
charmap "♀", "%"
+ charmap "”", "\""
-; TX_LARGE symbols from v0Tiles2 (full tile length)
-TX_FIRE EQUS "$05, $01"
-TX_GRASS EQUS "$05, $02"
-TX_LIGHTNING EQUS "$05, $03"
-TX_WATER EQUS "$05, $04"
-TX_FIGHTING EQUS "$05, $05"
-TX_PSYCHIC EQUS "$05, $06"
-TX_COLORLESS EQUS "$05, $07"
-TX_HP EQUS "$05, $10"
-TX_LVL EQUS "$05, $11"
-TX_No EQUS "$05, $13"
+; TX_SYMBOL (full-tile symbols loaded into v0Tiles2)
+ charmap "<", TX_SYMBOL
+ charmap " >", $00
+ charmap "FIRE>", $01
+ charmap "GRASS>", $02
+ charmap "LIGHTNING>", $03
+ charmap "WATER>", $04
+ charmap "FIGHTING>", $05
+ charmap "PSYCHIC>", $06
+ charmap "COLORLESS>", $07
+ charmap "POISONED>", $08
+ charmap "ASLEEP>", $09
+ charmap "CONFUSED>", $0a
+ charmap "PARALYZED>", $0b
+ charmap "HP>", $10
+ charmap "Lv>", $11
+ charmap "No>", $13
+ charmap "🌕>", $16
+ charmap "🌑>", $17
+ charmap "0>", $20
+ charmap "1>", $21
+ charmap "2>", $22
+ charmap "3>", $23
+ charmap "4>", $24
+ charmap "5>", $25
+ charmap "6>", $26
+ charmap "7>", $27
+ charmap "8>", $28
+ charmap "9>", $29
diff --git a/src/engine/home.asm b/src/engine/home.asm
index d6d2bc0..002488d 100644
--- a/src/engine/home.asm
+++ b/src/engine/home.asm
@@ -6174,7 +6174,7 @@ Uppercase: ; 23b1 (0:23b1)
ret c
cp $7b
ret nc
- sub $20
+ sub "a" - "A"
ld e, a
ret
@@ -6228,7 +6228,7 @@ Func_23d3: ; 23d3 (0:23d3)
INCROM $23fd, $245d
; convert the number at hl to large (TX_LARGE) text format and write it to wcaa0
; replace leading zeros with $00
TwoByteNumberToLargeText_TrimLeadingZeros: ; 245d (0:245d)
push de
@@ -6252,14 +6252,14 @@ TwoByteNumberToLargeText_TrimLeadingZeros: ; 245d (0:245d)
.digit_loop
inc hl
ld a, [hl]
- cp $20
+ cp LOW("<0>")
jr nz, .done ; jump if not zero
- ld [hl], $0 ; trim leading zero
+ ld [hl], LOW("< >") ; trim leading zero
inc hl
dec e
jr nz, .digit_loop
dec hl
- ld [hl], $20
+ ld [hl], LOW("<0>")
.done
dec hl
pop bc
@@ -6267,10 +6267,10 @@ TwoByteNumberToLargeText_TrimLeadingZeros: ; 245d (0:245d)
ret
.get_digit
- ld a, TX_LARGE
+ ld a, TX_SYMBOL
ld [de], a
inc de
- ld a, $20 - 1
+ ld a, LOW("<0>") - 1
.substract_loop
inc a
add hl, bc
@@ -7486,7 +7486,7 @@ Func_2d43: ; 2d43 (0:2d43)
ld a, [hli]
or a ; TX_END
jr z, .asm_2d79
- cp TX_LARGE
+ cp TX_SYMBOL
jr c, .asm_2d65
cp $10
jr nc, .asm_2d65
@@ -6228,7 +6228,7 @@ Func_23d3: ; 23d3 (0:23d3)
INCROM $23fd, $245d
-; convert the number at hl to large (TX_LARGE) text format and write it to wcaa0
+; convert the number at hl to TX_SYMBOL text format and write it to wcaa0
; replace leading zeros with $00
TwoByteNumberToLargeText_TrimLeadingZeros: ; 245d (0:245d)